@@ -50,17 +50,21 @@ sub _detect {
     $dirs = File::Spec->catdir($dirs, $file) if $file ne '';
 
     my @dir = File::Spec->splitdir($dirs);
+    unshift @dir, $volume if $volume;
 
     while (@dir) {
-        my $location = File::Spec->catfile(@dir, '.kritikarc');
-
-        return $location if -f $location;
+        for ($self->_rc_names) {
+            my $location = File::Spec->catfile(@dir, $_);
+            return $location if -f $location;
+        }
 
         pop @dir;
     }
 
-    my $location = File::Spec->catfile(File::HomeDir->my_home, '.kritikarc');
-    return $location if -f $location;
+    for ($self->_rc_names) {
+        my $location = File::Spec->catfile(File::HomeDir->my_home, $_);
+        return $location if -f $location;
+    }
 
     return;
 }
@@ -88,4 +92,8 @@ sub _parse {
     return $options;
 }
 
+sub _rc_names {
+    return ('.kritikarc', '_kritikarc');
+}
+
 1;
